#
# spec file for package kf6-kdoctools
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt6_version 6.7.0

%define rname kdoctools
# Full KF6 version (e.g. 6.8.0)
%{!?_kf6_version: %global _kf6_version %{version}}
# Last major and minor KF6 version (e.g. 6.0)
%{!?_kf6_bugfix_version: %define _kf6_bugfix_version %(echo %{_kf6_version} | awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           kf6-kdoctools
Version:        6.8.0
Release:        1.1
Summary:        Tools to create documentation from DocBook
License:        LGPL-2.1-or-later AND MIT
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  docbook_4
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{_kf6_bugfix_version}
BuildRequires:  perl-URI
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF6Archive) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(KF6I18n) >= %{_kf6_bugfix_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libxslt)
Provides:       kf6-kdoctools-doc = %{version}
Obsoletes:      kf6-kdoctools-doc < %{version}
# The XSL templates reference files in here
Requires:       docbook-xsl-stylesheets

%description
Provides tools to generate documentation in various format from DocBook files.

%package -n libKF6DocTools6
Summary:        Library to create documentation from DocBook
Requires:       kf6-kdoctools >= %{version}

%description -n libKF6DocTools6
Provides tools to generate documentation in various format from DocBook files.

%package devel
Summary:        Build environment for kdoctools
Requires:       docbook-xsl-stylesheets
Requires:       kf6-extra-cmake-modules >= %{_kf6_bugfix_version}
Requires:       libKF6DocTools6 = %{version}
Requires:       libxslt-devel
Requires:       cmake(Qt6Core) >= %{qt6_version}

%description devel
Provides tools to generate documentation in various format from DocBook files.
Development files.

%lang_package

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6 -DBUILD_QCH:BOOL=TRUE

%kf6_build

%install
%kf6_install

%fdupes %{buildroot}

%find_lang kdoctools6 --with-man --all-name

%ldconfig_scriptlets -n libKF6DocTools6

%files
%{_kf6_datadir}/kdoctools/
%{_kf6_bindir}/meinproc6
%{_kf6_bindir}/checkXML6
# The HTML files need to be in the main package or khelpcenter will have
# display issues
%{_kf6_htmldir}/*/
%doc %lang(en) %{_kf6_mandir}/*/meinproc6.*
%doc %lang(en) %{_kf6_mandir}/*/checkXML6.*
%doc %lang(en) %{_kf6_mandir}/*/kf6options.*
%doc %lang(en) %{_kf6_mandir}/*/qt6options.*

%files -n libKF6DocTools6
%license LICENSES/*
%doc README*
%{_kf6_libdir}/libKF6DocTools.so.*

%files devel
%doc %{_kf6_qchdir}/KF6DocTools.*
%{_kf6_cmakedir}/KF6DocTools/
%{_kf6_includedir}/KDocTools/
%{_libdir}/libKF6DocTools.so

%files lang -f kdoctools6.lang
%if 0%{?suse_version} == 1500
%{_kf6_mandir}/tr/
%endif

%changelog
* Mon Nov  4 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.8.0
- Changes since 6.7.0:
  * Update dependency version to 6.8.0
  * Upload new file sq.xml
  * Update version to 6.8.0
* Mon Oct  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.7.0
- Changes since 6.6.0:
  * Update dependency version to 6.7.0
  * Provide option to enable relocatable docbook files on non WIN32 platforms
  * Update version to 6.7.0
* Sat Sep  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.6.0
- Changes since 6.5.0:
  * Update version to 6.6.0
* Mon Aug  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.5.0
- Changes since 6.4.0:
  * Update dependency version to 6.5.0
  * Update version to 6.5.0
* Tue Jul  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.4.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.4.0
- Changes since 6.3.0:
  * remove silly goose from template
  * gitignore: add VS Code dir
* Wed Jun  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.3.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.3.0/
- Changes since 6.2.0:
  * Remove explicit maintainer from metainfo
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- No code change since 6.1.0
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Changes since 6.0.0:
  * update version for new release
  * Fixes compile problem for projects which uses older cmake versions
  * kdoctools_create_handbook/manpage: check INSTALL_DESTINATION for empty value
  * Replace user.entities
  * Upload New File bg.xml
  * Update user.entities in bg
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * update version for new release
  * Add myself as a contributor entity
  * Update Turkish entities
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Sat May 27 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-kdoctools
